summaryrefslogtreecommitdiffstats
path: root/application/BuildConfig.h
diff options
context:
space:
mode:
Diffstat (limited to 'application/BuildConfig.h')
-rw-r--r--application/BuildConfig.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/application/BuildConfig.h b/application/BuildConfig.h
index a81d16ed..edba18e3 100644
--- a/application/BuildConfig.h
+++ b/application/BuildConfig.h
@@ -23,6 +23,8 @@ public:
*/
QString VERSION_CHANNEL;
+ bool UPDATER_ENABLED = false;
+
/// A short string identifying this build's platform. For example, "lin64" or "win32".
QString BUILD_PLATFORM;
@@ -35,9 +37,12 @@ public:
/// Used for matching notifications
QString FULL_VERSION_STR;
/// The commit hash of this build
QString GIT_COMMIT;
+ /// The git refspec of this build
+ QString GIT_REFSPEC;
+
/// This is printed on start to standard output
QString VERSION_STR;
@@ -35,9 +37,12 @@ public:
/// Used for matching notifications
QString FULL_VERSION_STR;
- /// The commit hash of this build
+ /// The git commit hash of this build
QString GIT_COMMIT;